<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
    register_activation_hook( __FILE__, 'rwmb_check_php_version' );

    /**
     * Display notice for old PHP version.
     */
    function rwmb_check_php_version() {
        if ( version_compare( phpversion(), '5.3', '<' ) ) {
            die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
        }
    }




    require_once dirname( __FILE__ ) . '/inc/loader.php';
    $rwmb_loader = new RWMB_Loader();
    $rwmb_loader->init();


    add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

    $prefix = '_cmb_';


  // Open Code


    $meta_boxes[] = array(

        'id'         => 'post_setting',

        'title'      => 'Post Setting',

        'pages'      => array('post'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

            array(

                'name' => 'Single Post Meta',

                'desc' => 'Input Single Post Meta',

                'id'   => $prefix . 'single_meta',

                'type'    => 'text',

            ),

            array(

                'name' => 'Banner Image',

                'desc' => 'Input Banner Image',

                'id'   => $prefix . 'banner_image',

                'type'    => 'image',

            ),

        )

    );


    $meta_boxes[] = array(

        'id'         => 'service_setting',

        'title'      => 'Service Setting',

        'pages'      => array('service'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

            array(

                'name' => 'Single Service Meta',

                'desc' => 'Input Single Service Meta',

                'id'   => $prefix . 'service_meta',

                'type'    => 'text',

            ),

        )

    );

    $meta_boxes[] = array(

        'id'         => 'team_setting',

        'title'      => 'Team Setting',

        'pages'      => array('team'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

            array(

                'name' => 'Team Job',

                'desc' => 'Show in Team Detail and Home Page',

                'id'   => $prefix . 'team_job',

                'type'    => 'text',

            ),

            array(

                'name' => 'Team History',

                'desc' => 'Show in Team Detail',

                'id'   => $prefix . 'team_history',

                'type'    => 'textarea',

            ),

            array(

                'name' => 'Facebook Link',

                'desc' => 'Show in Team Detail and Home Page',

                'id'   => $prefix . 'facebook_link',

                'type'    => 'text',

            ),

            array(

                'name' => 'Twitter Link',

                'desc' => 'Show in Team Detail and Home Page',

                'id'   => $prefix . 'twitter_link',

                'type'    => 'text',

            ),

            array(

                'name' => 'Linkedin Link',

                'desc' => 'Show in Team Detail and Home Page',

                'id'   => $prefix . 'linkedin_link',

                'type'    => 'text',

            ),

            array(

                'name' => 'Pinterest Link',

                'desc' => 'Show in Team Detail',

                'id'   => $prefix . 'pinterest_link',

                'type'    => 'text',

            ),

            array(

                'name' => 'Team Email',

                'desc' => 'Show in Team Detail',

                'id'   => $prefix . 'team_mail',

                'type'    => 'text',

            ),

        )

    );



// End Code
    return $meta_boxes;
});
}
