<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class HomeServices extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'home-services';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Home Services Widget', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Slider widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-favorite';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Slider widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'home' ];
    }

    public function get_keywords() {
        return [ 'services', 'carousel' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_services',
            [
                'label' => esc_html__( 'Services Area', 'bdevs-elementor' ),
            ]
        );

        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'It is Heading', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'sub_heading',
            [
                'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
                'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'post_number',
            [
                'label'       => __( 'Post Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Post Number', 'bdevs-elementor' ),
                'default'     => __( '6', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );

        $this->add_control(
            'link',
            [
                'label'       => __( 'Link', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your Link', 'bdevs-elementor' ),
                'default'     => __( '#', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );  

        $this->add_control(
            'button',
            [
                'label'       => __( 'Button', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
                'default'     => __( '', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Image Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [   
                    [
                        'name'    => 'tab_image',
                        'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),
                    ],
                    [
                        'name'        => 'tab_link',
                        'label'       => esc_html__( 'Link', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                    ],
                ],
            ]

        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'center',
            ]
        ); 

        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_sub_heading',
            [
                'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_button',
            [
                'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();

    }

    public function render() {

        $settings  = $this->get_settings_for_display();
        ?>

        <section id="services" class="services section-padding bg-grey" data-scroll-index="2">
            <div class="container">
                <div class="row">
                    <div class="col-md-12">
                        <div class="title mb-30"> 
                            <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
                                <span><?php echo wp_kses_post($settings['sub_heading']); ?></span>
                                <?php endif; ?>
                                <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
                                <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
                                <?php endif; ?>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12 mb-30">
                        <div class="owl-carousel owl-theme text-center">

                        <?php 
                        $order = $settings['post_order'];
                        $post_number = $settings['post_number'];
                        $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'service',  'orderby' => 'ID', 'order' => $order));

                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                            $service_meta = get_post_meta(get_the_ID(),'_cmb_service_meta', true);
                            ?>

                            <div class="item">
                                <div class="position-re o-hidden img-grayscale item-inner"> <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""> </div>
                                <div class="con"> <span class="category">
                                        <a href="<?php the_permalink();?>"><?php echo esc_attr($service_meta); ?></a>
                                    </span>
                                    <h5><a href="<?php the_permalink();?>"><?php the_title();?></a></h5> <a href="<?php the_permalink();?>"><i class="ti-arrow-right"></i></a>
                                </div>
                            </div>

                    <?php endwhile; ?>
                            
                        </div>
                    </div>
                </div>
                <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )): ?>
                <div class="row">
                    <div class="col-md-12 text-right"> <a class="underline-text" href="<?php echo wp_kses_post($settings['link']); ?>"><?php echo wp_kses_post($settings['button']); ?></a> </div>
                </div>
                <?php endif; ?>
            </div>
        </section>
        <!-- hr line -->
        <hr class="line-vr-section">
        <?php if (is_admin()) { ?>
<script type="text/javascript">
      $('.services .owl-carousel').owlCarousel({
        loop: true
        , margin: 30
        , mouseDrag: true
        , autoplay: false
        , dots: true
        , responsiveClass: true
        , responsive: {
            0: {
                items: 1
                , dots: false

            , }
            , 600: {
                items: 2
                , dots: false
  
            }
            , 1000: {
                items: 3
            }
        }
    });
</script>
<?php }  ?>
    <?php
    }

}
