<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class HomeTeam extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'home-team';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Home Team Widget', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Slider widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-favorite';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Slider widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'home' ];
    }

    public function get_keywords() {
        return [ 'team', 'carousel' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_team',
            [
                'label' => esc_html__( 'Team Area', 'bdevs-elementor' ),
            ]
        );

        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'It is Heading', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'sub_heading',
            [
                'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
                'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'post_number',
            [
                'label'       => __( 'Post Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Post Number', 'bdevs-elementor' ),
                'default'     => __( '3', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );

        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'center',
            ]
        ); 

        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_sub_heading',
            [
                'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();

    }

    public function render() {

        $settings  = $this->get_settings_for_display();
        ?>

        <section id="team" class="team section-padding bg-grey" data-scroll-index="5">
            <div class="container">
                <div class="row">
                    <div class="col-md-12">
                        <div class="title mb-30"> 
                            <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
                            <span><?php echo wp_kses_post($settings['sub_heading']); ?></span>
                        <?php endif; ?>
                        <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
                        <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12 owl-carousel owl-theme">

                <?php 
                $order = $settings['post_order'];
                $post_number = $settings['post_number'];
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'team',  'orderby' => 'ID', 'order' => $order));

                while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                    $team_job = get_post_meta(get_the_ID(),'_cmb_team_job', true);
                    $team_mail = get_post_meta(get_the_ID(),'_cmb_team_mail', true);
                    $facebook_link = get_post_meta(get_the_ID(),'_cmb_facebook_link', true);
                    $twitter_link = get_post_meta(get_the_ID(),'_cmb_twitter_link', true);
                    $linkedin_link = get_post_meta(get_the_ID(),'_cmb_linkedin_link', true);
                    ?>
                    <div class="item">
                        <div class="img img-grayscale item-inner"><a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a></div>
                        <div class="info">
                            <h5><?php the_title();?></h5>
                            <?php if($team_job != ''){?>
                                <h6><?php echo esc_attr($team_job); ?></h6>
                            <?php }?>
                            <div class="social valign">
                                <div class="full-width"> 
                                    <?php if($facebook_link != ''){?>
                                        <a href="<?php echo esc_url($facebook_link); ?>"><i class="ti-facebook"></i></a>
                                    <?php }?>
                                    <?php if($twitter_link != ''){?>
                                        <a href="<?php echo esc_url($twitter_link); ?>"><i class="ti-twitter"></i></a>
                                    <?php }?>
                                    <?php if($linkedin_link != ''){?>
                                        <a href="<?php echo esc_url($linkedin_link); ?>"><i class="ti-linkedin"></i></a>
                                    <?php }?>
                                    <?php if($team_mail != ''){?>
                                        <p><?php echo esc_url($team_mail); ?></p>
                                    <?php }?>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
            </div>
        </div>
    </div>
</section>
<!-- hr line -->
<hr class="line-vr-section">
<?php if (is_admin()) { ?>
<script type="text/javascript">
      $('.team .owl-carousel').owlCarousel({
        loop: true
        , margin: 30
        , dots: true
        , mouseDrag: true
        , autoplay: false
        , responsiveClass: true
        , responsive: {
            0: {
                items: 1
                , dots: false
        
            }
            , 600: {
                items: 2
                , dots: false
        
            }
            , 1000: {
                items: 3
            }
        }
    });
</script>
<?php }  ?>
        
    <?php
    }

}
