<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class PagePricing extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'page-pricing';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Page Pricing Widget', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Slider widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-favorite';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Slider widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'page' ];
    }

    public function get_keywords() {
        return [ 'pricing', 'carousel' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_pricing',
            [
                'label' => esc_html__( 'Pricing Area', 'bdevs-elementor' ),
            ]
        );

        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'It is Heading', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'sub_heading',
            [
                'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
                'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Pricing Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [   
                    [
                        'name'    => 'tab_image',
                        'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),
                    ],
                    [
                        'name'        => 'tab_title',
                        'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                    ],
                    [
                        'name'        => 'tab_unit',
                        'label'       => esc_html__( 'Unit', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                    ],
                    [
                        'name'        => 'tab_price',
                        'label'       => esc_html__( 'Price', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                    ],
                    [
                        'name'        => 'tab_content',
                        'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                    ],
                ],
            ]

        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'center',
            ]
        ); 

        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_sub_heading',
            [
                'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();

    }

    public function render() {

        $settings  = $this->get_settings_for_display();
        ?>

        <section id="pricing" class="section-padding bg-grey" data-scroll-index="4">
            <div class="container">
                <div class="row">
                    <div class="col-md-12">
                        <div class="title mb-30"> 
                            <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
                            <span><?php echo wp_kses_post($settings['sub_heading']); ?></span>
                        <?php endif; ?>
                        <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
                        <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <div class="row">
            <?php foreach ( $settings['tabs'] as $item ) : ?>
                <div class="col-md-4">
                    <div class="price-box">
                        <?php if ( '' !== $item['tab_image']['url'] ) : ?>
                            <div class="price-box-inner img-grayscale" style="background-image: url(<?php echo wp_kses_post($item['tab_image']['url']); ?>)">
                                <ul>
                                    <?php if ( '' !== $item['tab_title'] ) : ?>
                                        <li class="pricing-title">
                                            <h3 class="pricing-pt-title"><?php echo wp_kses_post($item['tab_title']); ?></h3>
                                        </li>
                                    <?php endif; ?>
                                    <li class="pricing-prices"> 
                                        <?php if ( '' !== $item['tab_unit'] ) : ?>
                                            <sup class="pricing-dolar"><?php echo wp_kses_post($item['tab_unit']); ?></sup> 
                                        <?php endif; ?>
                                        <?php if ( '' !== $item['tab_price'] ) : ?>
                                            <span class="pricing-price" style="color: #ffffff"><?php echo wp_kses_post($item['tab_price']); ?></span> 
                                        <?php endif; ?>
                                    </li>
                                    <?php if ( '' !== $item['tab_content'] ) : ?>
                                        <li class="pricing-content">
                                            <ul>
                                                <?php echo wp_kses_post($item['tab_content']); ?>
                                            </ul>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>
</section>

        
    <?php
    }

}
